/v1/projects/{project_id}/vpcs/vms — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/vpcs/vms

Contents

- /v1/projects/{project_id}/vpcs/vms
  - POST /v1/projects/{project_id}/vpcs/vms
    - Parameters
    - Response status codes
    - Input
    - Output

## POST /v1/projects/{project_id}/vpcs/vms

Create a new VPCS instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
name | ✔ | string | VPCS VM name
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
vm_id |  |  | VPCS VM identifier

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS VM name
project_id | ✔ | string | Project UUID
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
vm_id | ✔ | string | VPCS VM UUID

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »